==> haskell-crypto-cipher-types-0.0.9-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-AfrbXuzMbdh1qMQIWJkaB4
key: crypto-cipher-types-0.0.9-AfrbXuzMbdh1qMQIWJkaB4
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: acd7996cbed663230371df7d4b0c641f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-AfrbXuzMbdh1qMQIWJkaB4
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-27iPpKEc5cx9pB9GAggjZj
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-CdzjsssYT8jDIjJnm4HawT
key: crypto-cipher-types-0.0.9-CdzjsssYT8jDIjJnm4HawT
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: 2dc4b15a909479f87e2d52fd419e3a7e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-cipher-types-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-crypto-cipher-types
hs-libraries: HScrypto-cipher-types-0.0.9-CdzjsssYT8jDIjJnm4HawT
depends:
    base-4.9.1.0 byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ
    bytestring-0.10.8.1 securemem-0.1.9-LqtmUJgYg9WFPGOoL0Jb3A
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
